cubicweb.preferences.js — CubicWeb 3.10.1

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Web side development »
- Javascript »
- <no title> »

# cubicweb.preferences.js

toggle visibility of an element by its id & set current visibility status in a cookie XXX whenever used outside of preferences, don’t forget to

> move me in a more appropriate place

### Navigation

- index
- modules |
- next |
- previous |
- CubicWeb 3.10.1 »
- Web side development »
- Javascript »
- <no title> »